#
# spec file for package python-masakariclient
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global oldpython python
Name:           python-masakariclient
Version:        8.4.0
Release:        1.2
Epoch:          0
Summary:        Python API and CLI for OpenStack Masakari
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/python-masakariclient
Source0:        https://files.pythonhosted.org/packages/source/p/python-masakariclient/python-masakariclient-8.4.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-PrettyTable
BuildRequires:  python3-ddt
BuildRequires:  python3-openstacksdk >= 0.13.0
BuildRequires:  python3-osc-lib >= 1.8.0
BuildRequires:  python3-oslo.serialization >= 2.18.0
BuildRequires:  python3-oslo.utils
BuildRequires:  python3-oslotest
BuildRequires:  python3-python-subunit
BuildRequires:  python3-requests-mock
BuildRequires:  python3-stestr
BuildRequires:  python3-testscenarios
BuildRequires:  python3-testtools
BuildArch:      noarch

%description
Client library for Masakari built on the Masakari API. It provides a Python API
(the masakariclient module) and a command-line tool (masakari).

%package -n python3-masakariclient
Summary:        Python API and CLI for OpenStack Masakari
Requires:       python3-openstacksdk >= 0.13.0
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.serialization >= 2.18.0
Requires:       python3-oslo.utils
Requires:       python3-pbr >= 2.0.0
Conflicts:      %oldpython-masakariclient < %version

%description -n python3-masakariclient
Client library for Masakari built on the Masakari API. It provides a Python API
(the masakariclient module) and a command-line tool (masakari).

This package contains the Python 3.x module.

%package -n python-masakariclient-doc
Summary:        Documentation for OpenStack Masakari API client libary
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme
%if 0%{?suse_version}
Obsoletes:      %oldpython-masakariclient < %version
%endif

%description -n python-masakariclient-doc
Client library for Masakari built on the Masakari API. It provides a Python API
(the masakariclient module) and a command-line tool (masakari).
This package contains the documentation.

%prep
%autosetup -p1 -n python-masakariclient-%{version}
%py_req_cleanup

%build
%{py3_build}

# Build HTML docs and man page
PBR_VERSION=8.4.0 %sphinx_build -b html doc/source doc/build/html
PBR_VERSION=8.4.0 %sphinx_build -b man doc/source doc/build/man
rm -r doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}
# man pages
install -p -D -m 644 doc/build/man/python-masakariclient.1 %{buildroot}%{_mandir}/man1/python-masakariclient.1

%check
%{openstack_stestr_run}

%files -n python3-masakariclient
%license LICENSE
%{python3_sitelib}/masakariclient
%{python3_sitelib}/*.egg-info

%files -n python-masakariclient-doc
%license LICENSE
%doc doc/build/html
%{_mandir}/man1/python-masakariclient.1.*

%changelog
* Sun Mar 24 2024 cloud-devel@suse.de
- update to version 8.4.0
  - Update python unit testing template
* Sun Jan 14 2024 cloud-devel@suse.de
- update to version 8.3.0
  - Update master for stable/xena
  - Add Python3 yoga unit tests
  - Fix tox4 issues
  - Update python testing classifier
  - Update master for stable/2023.1
  - Update master for stable/zed
  - Update master for stable/yoga
  - Drop Python 3.6 and 3.7 support
  - Add Python3 zed unit tests
  - support for Masakari VMove
  - Add Python3 antelope unit tests
* Mon Dec  6 2021 cloud-devel@suse.de
- update to version 7.1.0
  - Add Python3 xena unit tests
  - Fix url to docs
  - [CI] Run bandit
  - Fix home_page in setup.cfg
  - Update master for stable/wallaby
  - Use py3 as the default runtime for tox
  - setup.cfg: Replace dashes with underscores
  - [community goal] Update contributor documentation
  - Replace deprecated UPPER_CONSTRAINTS_FILE variable
* Sun May  2 2021 cloud-devel@suse.de
- update to version 7.0.0
  - Drop lower-constraints
  - Add 'is_enabled' attr to segment
  - Add Python3 wallaby unit tests
  - [goal] Migrate testing to ubuntu focal
  - Add py38 package metadata.
  - [CI] Add periodic jobs
  - [CI] Add openstackclient-plugin-jobs template
  - Update master for stable/victoria
  - remove unicode from code
  - Revert "remove py37"
  - Drop the legacy client
  - Add py38 package metadata
  - Fix docs reqs for new pip
  - Fix the plugin after removing the legacy client
  - Add release notes to readme.rst
  - Remove usage of six
  - Use unittest.mock instead of mock in the doc
  - Fix tox for py38 and lower-contraints
  - remove py37
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 6.1.1
  - Add Python3 victoria unit tests
  - Switch to newer openstackdocstheme and reno versions
  - Update master for stable/ussuri
  - Use unittest.mock instead of third party mock
  - remove future from lower-constraints
  - Remove translation sections from setup.cfg
  - drop mock from lower-constraints
  - Fix hacking min version to 3.0.1
  - Stop to use the __future__ module.
* Tue May 12 2020 cloud-devel@suse.de
- update to version 6.0.0
  - Update master for stable/train
  - Cleanup py27 support
  - [ussuri][goal] Drop python 2.7 support and testing
  - Update operator guide documentation
  - Update hacking for Python3
* Wed Mar 11 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 5.5.0
  - OpenDev Migration Patch
  - Update master for stable/stein
  - Replace git.openstack.org URLs with opendev.org URLs
  - Add Python 3 Train unit tests
  - [Gate Fix]Switch to stestr
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 5.4.0
  - Add --os-interface and --os-region-name options
  - Update the hacking to latest
  - Update the outdated URL in HACKING.rst
  - Add Python 3.6 classifier to setup.cfg
  - Run all jobs by default using python3
  - Fix osc command issue
  - Change openstack-dev to openstack-discuss
  - Add api_version support
  - Update reno for stable/rocky
  - Display progress_details of the notification
  - Use template for lower-constraints
  - Delete segment and host shouldn't ignore not found error
  - Deprecate masakari CLI
  - import zuul job settings from project-config
* Sat Sep  1 2018 cloud-devel@suse.de
- update to version 5.2.0
  - fix tox python3 overrides
  - Update for upcoming openstacksdk changes
  - Re-factor test cases to reduce code
  - Avoid tox_install.sh for constraints support
  - Add support for auto_priority, rh_priority recovery method
  - Updated from global requirements
  - add lower-constraints job
  - Remove masakariclient's proxy class
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 4.0.0
  - Fix failing test case for PY3
  - Bump openstacksdk to 0.9.13
  - Use os-testr and add PY35 support
  - Improve command arguments
  - Change the base class of osc.v1.DeleteHost
  - Add assertions to UT code
  - Re-factor test cases to reduce code
  - [Fix gate]Update test requirement
  - Remove unnecessary return statement
  - Fix failing gate jobs by fixing constraints support
  - Add support for auto_priority, rh_priority recovery method
  - Remove inproper comment for APIs.
  - Enable to specify name and ID when operating segments and hosts
* Mon Aug  7 2017 tbechtold@suse.com
- Initial packaging (version 3.0.1)
